@@ -18,12 +18,7 @@ if(.Platform$OS.type == "windows") {
 bannerAnal <- function()
 {
    page =  fluidPage(
-       
-              fluidRow( column(12, {
-                       tags$div(img(src = "images/analyse_banner.jpg", 
-                                 style="width: 100% ; height: 100%"))
-                               
-                                }
+              fluidRow( column(12, { tags$div(img(src = "images/analyse_banner.jpg", style="width: 100% ; height: 100%")) }
                       ) ## end column(12, )
               ), ## end fluidRow
               br(),
@@ -38,7 +33,6 @@ bannerAnal <- function()
 }
 
 row1Anal <- function(){
-
   page <-  fluidRow(column(12,  
                     wellPanel(
                        uiOutput("analyse_names"),
@@ -56,17 +50,17 @@ row1Anal <- function(){
 
 row2Anal <- function()
 {
-   page =   fluidRow(column(12,
-               wellPanel(
-                  uiOutput("analyse_fnames"),
-                       bsTooltip("analyse_fnames",
-                             title='<font size="3" > Select the variables, if any, to be used as fixed effects in the analysis. If no variables are selected, then only an overall mean will be fitted. </font>',
-                              placement="right", trigger="hover", options=list(container="body")),
-                       textOutput("fmodel")
-                         ) ## end wellPanel
-                       ) ## end column
-                   ) ## end fluidRow
-   return(page)
+ page =   fluidRow(column(12,
+          wellPanel(
+            uiOutput("analyse_fnames"),
+              bsTooltip("analyse_fnames",
+              title='<font size="3" > Select the variables, if any, to be used as fixed effects in the analysis. If no variables are selected, then only an overall mean will be fitted. </font>',
+                placement="right", trigger="hover", options=list(container="body")),
+              textOutput("fmodel")
+           ) ## end wellPanel
+                ) ## end column
+          ) ## end fluidRow
+return(page)
 }
 
 
@@ -88,8 +82,6 @@ page =  fluidRow(column(12,  wellPanel(
 
 row4Anal <- function()
 {
-
-
 page =  fluidRow( column(12, 
          wellPanel(
           radioButtons(inputId="analyse_gamma", label=h4("Step 4: Specify gamma value (controls the false positive rate)"), 
@@ -155,7 +147,7 @@ page =  fluidRow( column(12,
                                            
                                            
                         
-                                         
+return(page)                                         
 }  ## end function row4Analyse 
 
 
@@ -174,19 +166,122 @@ row5Anal <- function()
                                          icon=icon("upload", lib="glyphicon")),
                                           style='padding: 1px',
                                         bsTooltip("analyse_go",
-                     title='<font size="3" >  Click here to find the set of snp in strongest association with the trait. This may take some time if the gamma value is being found automatically.   </font>',
+                     title='<font size="3" >  Click here to find the set of snp in strongest association with the trait. Manually setting the gamma value is much faster than having the gamma value set automatically. However, automatically is the preferred option.  </font>',
                           placement="right", trigger="hover",
                           options=list(container="body"))
-              ) ## wellPanel
+             ) ## wellPanel
             )   ## column12
          ) ## end fluidRow
   return(page)
 }
 
 
+##-----------------------------------
+## Rows for Plotting Page 
+##-----------------------------------
+banner1Plot <- function(){
+  page <- fluidRow(
+             column(12, {
+                  tags$div(img(src = "images/plot_banner.jpg", style="width: 100% ; height: 100%"))
+                        }
+                   ) ## end column(12, )
+                  ) ## end fluidRow
+     return(page)
+}
+
+banner2Plot <- function(){
+   page <- fluidRow(column(12, 
+                       bsButton(inputId="plot_overview", label="Hover here for details",
+                       style="warning", size="large", type="action", block=TRUE,
+                       icon=icon("question-circle-o"))
+                           ) ## end column
+                   ) ## end fluidRow
+           return(page)             
+}
+
+col1Plot <-   function(){ 
+   page <-  column(3,
+                   wellPanel( 
+                      uiOutput("plot_choice"), 
+
+                      bsTooltip("plot_choice",
+                     title='<font size="3" > Manhattan plot type -  score statistics are converted into  p-values and their -log values plotted on the y-axis. Score statistic plot type - the score statistics are plotted on the y-axis. The score statistics are used by Eagle to identify the SNP in strongest association with the trait.  A new set of score statistics are generated at each iteration of the model buidling process. </font>',
+                      placement="right", trigger="hover", options=list(container="body"))
+
+                 ) ## end wellPanel
+             )  # column
+  return(page)
+}
 
 
 
+col2Plot <- function(){
+  page <-  column(3,
+                  wellPanel(
+                    uiOutput("plot_modelits"),
+                    bsTooltip("plot_modelits",
+                       title='<font size="3" > SNP-trait associations are found by building the best model iteratively.  </font>',
+                       placement="right", trigger="hover", options=list(container="body"))
+
+                  ) ## end wellPanel
+           ) ## end column
+  return(page)
+}
+
+
+col3Plot <- function(){
+
+  page <-  column(3,
+             wellPanel(
+               uiOutput("plot_chromosomes"),
+
+               bsTooltip("plot_chromosommes",
+               title='<font size="3" > Select a chromosome or the entire genome (All)  </font>',
+               placement="right", trigger="hover", options=list(container="body"))
+
+            ) ## end wellPanel
+          ) ## end column
+  return(page)
+}
+
+
+col4Plot <- function()
+{
+   page = column(3,
+             wellPanel(
+                shinyjs::useShinyjs(),
+                            actionButton(inputId="plot_go",label=HTML('<font size="4">Generate Plot</font>'), width='100%', style='padding:1px 1px 1px 1px; font-size:100%'),
+                                          style='padding: 1px',
+                                        bsTooltip("plot_go",
+                     title='<font size="3" >   Press this button to generate the plot. If you change your selections after the plot has been created, you will need to click this button again to recreate the plot.  </font>',
+                          placement="left", trigger="hover",
+                          options=list(container="body"))
+            ) ## wellPanel
+         )   ## column3
+  return(page)
+}
+
+##---------------------------
+## Rows for Help page
+##---------------------------
+
+row1Help <- function(){
+  page <- fluidRow(
+             column(12, 
+               includeHTML("help.html")
+             )  ## end column
+          ) ## end fluidRow
+  return(page)
+ }
+
+
+
+
+
+#------------------------------
+# Misc functions
+#------------------------------
+
 
 home_intro <- function(){
   txt <- "
@@ -217,8 +312,9 @@ read_pheno_intro <- function(){
     
   
 
-
-
+##-------------------
+## ui Body
+##--------------------
 
 ## ui.R ##
 library(shiny)
@@ -226,10 +322,13 @@ library(shinythemes)
 library(shinyBS)
 library(shinyjs)
 library(shinyFiles)
+library(ggthemes)
+library(ggplot2)
 
-FullPage <- navbarPage(title="Eagle: Genome-wide association mapping",  theme = shinytheme("flatly"),
-                #       theme = shinytheme("slate"),
-                #       theme = shinytheme("united"),
+FullPage <- navbarPage(title="Eagle: Genome-wide association mapping",  
+                      theme = shinytheme("flatly"),
+                #       theme = shinytheme("paper"),
+                #      theme = shinytheme("united"),
 
                       
                        ##----------------------------##
@@ -401,7 +500,7 @@ placement="right", trigger="hover",
 
                                                           style='padding: 1px',
                                                           bsTooltip("marker_go", 
-title='<font size="3" > Upload file. <br> This may take some time if the file is large.  </font>',
+title='<font size="3" > Upload marke data file. <br> This may take some time if the file is large.  </font>',
 placement="right", trigger="hover",
                                                                      options=list(container="body"))
 
@@ -558,7 +657,7 @@ placement="right", trigger="hover",
 
                                                           style='padding: 1px',
                                                           bsTooltip("pheno_go",
-title='<font size="3" > Upload file. <br> This may take some time if the file is large. </font>',
+title='<font size="3" > Upload phenotypic file.  This file can contain multiple trait and covariate data.</font>',
 placement="right", trigger="hover",
                                                                      options=list(container="body"))
 
@@ -770,7 +869,7 @@ placement="right", trigger="hover",
 
                                                           style='padding: 1px',
                                                           bsTooltip("Zmat_go",
-title='<font size="3" > Upload file.    </font>',
+title='<font size="3" > Upload Z matrix file.    </font>',
 placement="right", trigger="hover",
                                                                      options=list(container="body"))
  
@@ -916,7 +1015,7 @@ placement="right", trigger="hover",
 
                                                           style='padding: 1px',
                                                           bsTooltip("map_go",
-title='<font size="3" > Upload file. <br> This may take some time if the file is large.   </font>',
+title='<font size="3" > Upload marker map file.    </font>',
 placement="right", trigger="hover",
                                                                      options=list(container="body"))
  
@@ -945,6 +1044,8 @@ placement="right", trigger="hover",
                                 
                       ),  ## end tabPanel("Read Map")
 
+
+
                   ##-------------------------------------##
                   ## Analysis                            ##
                   ##-------------------------------------##
@@ -1007,7 +1108,7 @@ placement="right", trigger="hover",
 
 
 
-
+                      navbarMenu("More", 
 
 
  
@@ -1093,7 +1194,7 @@ tags$div(
                                 column(12, 
                                     conditionalPanel(condition="input.pvalue_go > 0", 
 tags$div(
-         HTML(paste( tags$span(style="color: #ad1d28; font-size: 22px", "Size and Significance of Effects"), sep = ""))),
+         HTML(paste( tags$span(style="color: #ad1d28; font-size: 22px", "Significance of Effects"), sep = ""))),
                                     tableOutput("size")
 
                                     ) ## end conditionalPanel
@@ -1120,18 +1221,46 @@ tags$div(
 
 ),  ## end tabPAnel pvalue
 
+##----------------------------##
+## Plotting                   ##
+##----------------------------##
+  tabPanel("Plots", icon=icon("fa-pie-chart", class="fa fa-pie-chart fa-lg"),
+     tags$head(tags$style(HTML('.popover { max-width: 80%; } '))),
+   fluidPage(
+      banner1Plot(),
+      br(),
+      banner2Plot(),
+      br(),
+      fluidRow(
+         col1Plot(),
+         col2Plot(),
+         col3Plot(),
+         col4Plot()
+      ), ## end fluidRow
+      fluidRow(
+        textOutput("caption")
+      ),
+      fluidRow(
+         ## plotly plot
+         plotOutput("plot")
+      ) ## end fluidRow
+     ) ## end fluidPage    
+   ),  ## end tabPanel("Plots")
+
+
+##------------------------------##
+## Help                         ##
+##------------------------------##
 
    tabPanel("Help",  icon=icon("question-circle-o", class="fa fa-question-circle-o fa-lg  "),
-                fluidPage(
-                      fluidRow(
-                        column(12, 
-                            includeHTML("help.html")
-                        )  ## end column
-                      ) ## end fluidRow
-                 ) ## end fluidPage
-            ) ## end tabPanel("Help") 
+   fluidPage(
+     row1Help()
 
 
+     ) ## end fluidPage
+    ) ## end tabPanel("Help") 
+
+       ) ## end navbarMenu
 
 
 
@@ -1439,16 +1568,6 @@ server <- function(input, output, session){
   })  ## end observeEvent
 
 
-  ##------------------
-  ## Optimize
-  ##------------------
-
-
-
-
-
-
-
 
 
   ##-------------------
@@ -1512,6 +1631,9 @@ server <- function(input, output, session){
 
 
 
+
+
+
   output$analyse_fnames <- renderUI({
       checkboxGroupInput("nmsf", h4("Step 2: Choose fixed effects"), fnms() , inline=TRUE)
     })  ## end renderUI
@@ -1525,6 +1647,8 @@ server <- function(input, output, session){
 
 
 
+
+
  ##  AM analysis for calculation of FPR
 # res <- NULL
 setgamma <- 1
@@ -1558,13 +1682,14 @@ setgamma <- 1
                  res <<- FPR4AM(numreps = input$analyse_numreps,  falseposrate=input$analyse_fpr,
                             trait=input$nmst , fformula=fform , availmemGb = input$memsize , 
                             ncpu = input$analyse_cpu,  pheno = pheno, geno=geno, map=map, Zmat = Zmat) 
-          
-                 setgamma <<- res$setgamma
+         
+                  if(!is.null(res)){ 
+                    setgamma <<- res$setgamma
                  
-                 res <<- AM(trait=input$nmst , fformula=fform , availmemGb = input$memsize ,
+                    res <<- AM(trait=input$nmst , fformula=fform , availmemGb = input$memsize ,
                              gamma=res$setgamma,
                              ncpu = input$analyse_cpu,  pheno = pheno, geno=geno, map=map, Zmat=Zmat)
-
+                  }
 
                  },  ## end withCallingHandlers
                     message = function(m) {
@@ -1576,9 +1701,302 @@ setgamma <- 1
   })  ## end observeEvent
 
 
+ ##----------------------------------
+ ## Plotting  - server code -
+ ##----------------------------------
+
+  #----------------------------------------------------
+  ## get chromosome labels
+  chromnames <- reactive({
+             if (input$analyse_go){
+                 # map has been entered
+                  if (input$map_go){
+                     return(c(unique(map[,2]), "All") )
+                  } else {
+                    # no map 
+                     return(1)
+                  }
+             }
+           })
 
 
 
+  sz <- 0
+  output$plot_chromosomes <- renderUI({
+
+   if (length(chromnames) < 5){
+       sz <- length(chromnames)
+   } else {
+       sz <- 5
+   }
+  
+  selectInput(inputId="chosenchrm", label=h4("Choose chromosome"), choices=chromnames() , size = sz   , selectize=FALSE )     
+  })  ## end renderUI
+  #----------------------------------------------------
+
+
+  #----------------------------------------------------
+  ## get number of iterations of model building 
+  modelits <- reactive({
+                if(input$analyse_go){
+                  return(c(1:length(res$Mrk)))
+                }
+  })
+
+
+  sz <- 0
+  output$plot_modelits <- renderUI({
+
+   if (length(modelits) < 5){
+       sz <- length(modelits)
+   } else {
+       sz <- 5
+   }
+
+  selectInput(inputId="chosenits", label=h4("Choose iteration"), choices=modelits() , size = sz   , selectize=FALSE )    
+  })  ## end renderUI
+
+  #----------------------------------------------------
+
+
+
+  #----------------------------------------------------
+
+   output$plot_choice <- renderUI({
+       radioButtons(inputId="plotchoice", label=h4("Choose plot type"),
+                       choiceNames=c("Manhattan (-log(p))","Score statistics"),
+                       choiceValues=c("manhattan", "raw") )
+   })
+
+  #----------------------------------------------------
+
+   IsItBigger <- function(vals, itnum, xindx=NULL){
+   ## calculates percentage change in size (increase or decrease)
+   bigger <- NULL
+   percentagechange <- NULL
+   if(as.numeric(itnum) > 1){
+       # entire genome
+       bigger <- rep("" , length(vals[[as.numeric(itnum)]]) ) ## initialize 
+       percentagechange <- rep(0, length(vals[[as.numeric(itnum)]]) ) ## initialize
+       a <-  vals[[as.numeric(itnum)]]
+       b <- vals[[as.numeric(itnum) - 1 ]]
+       # a > b       
+       indx <- which( a  >  b )
+       bigger[indx] <- "Increased value"
+       percentagechange[indx] <- ( (a  -    b ) )[indx] 
+       # a < b
+       indx <- which( a <=  b  )
+       bigger[indx] <- "Decreased value"
+       percentagechange[indx] <- ( (b  -    a ) )[indx] 
+      
+       if(!is.null(xindx)){
+          # reduce to chromosome
+          bigger <- bigger[xindx]
+          percentagechange <- percentagechange[xindx]
+       }
+     }
+     res <- list(bigger=bigger, percentagechange=percentagechange)
+     return(res)
+  }
+
+
+  #---------------------------------------------------
+  # ggplot plotting function
+ observeEvent(input$plot_go , {
+
+     # we do not have a map
+     xindx <- 1:length( res$outlierstat[[as.numeric(input$chosenits)]] )
+     xvals <- xindx
+
+     yvals <- res$outlierstat[[as.numeric(input$chosenits)]]
+     isit  <- IsItBigger(vals=res$outlierstat, itnum=input$chosenits )
+     bigger <- isit$bigger
+     percentagechange <- isit$percentagechange
+     chrm <- rep(1, length(xindx))
+     pos  <- xvals 
+ 
+     # map exisits
+     if(!is.null(map)){
+        if(input$chosenchrm != "All"){
+          # picking a single chrm to plot
+          xindx <- which(as.character(map[,2]) == input$chosenchrm)
+          xvals <- map[xindx, ncol(map)]
+          chrm <-  map[xindx, 2]
+          pos <- xvals 
+          yvals <-  res$outlierstat[[as.numeric(input$chosenits)]][xindx]
+          isit <- IsItBigger(vals=res$outlierstat, itnum=input$chosenits, xindx=xindx )
+          bigger <- isit$bigger
+          percentagechange <- isit$percentagechange
+       } else {
+          # plotting all the chromosomes - more difficult
+          # reordering based on chrm then map position
+          oindx <- order(map[,2], map[, ncol(map)])
+          yvals <- res$outlierstat[[as.numeric(input$chosenits)]][oindx]  ## reordering yvals
+
+          if( as.numeric(input$chosenits)  > 1){
+             bigger <- rep(""    , length(  res$outlierstat[[as.numeric(input$chosenits)]][oindx] ) )
+             percentagechange <- rep(0, length(  res$outlierstat[[as.numeric(input$chosenits)]][oindx] ) )
+
+
+            a <-  res$outlierstat[[as.numeric(input$chosenits)]][oindx]
+            b <- res$outlierstat[[as.numeric(input$chosenits) - 1 ]][oindx]
+
+             indx <- which(  a >  b )
+             bigger[indx] <- "Increased value"
+             percentagechange[indx] <-  (( b - a)) [indx]
+
+             indx <- which(  a <=  b )
+             bigger[indx] <- "Decreased value"
+             percentagechange[indx] <-  (( a - b)) [indx]
+
+          }
+
+          mapordered <- map[oindx,]
+          # map position is within chrm, need cumulative postion. 
+          chrms <- unique(mapordered[,2])
+          xvals <- mapordered[, ncol(mapordered)]
+          if (length(chrms) > 1){
+            xvals <- rep(0, nrow(mapordered))
+            indx <- which(mapordered[,2] == chrms[1])
+            xvals[indx] <- mapordered[indx,ncol(mapordered)]
+            genometot <- max(xvals)
+             for(ii in chrms[-1]){
+               indx <- which(mapordered[,2] == ii)
+               xvals[indx] <- mapordered[indx, ncol(mapordered)] + genometot
+               genometot <- max(xvals)
+              }  ## end for
+          } ## end if length(chrms)
+           chrm <- mapordered[,2]
+           pos <- mapordered[, ncol(mapordered)]
+       }  # if else 
+       
+
+     }  ##  if(!is.null(map))
+
+    xlabel <- "Map Position (bp)"
+    if(is.null(map))
+      xlabel <- "Column Position of SNP"
+
+    ylabel <- "Score Statistic"
+    if(input$plotchoice=="manhattan")
+       ylabel <- "-log10(p value)"
+    
+
+     # addition on SNP-trait positions on map
+     if(length(res$Chr) > 1){  ## first entry of list is always NA
+         # found associations 
+          found.chr <- res$Chr[!is.na(res$Chr)]
+          found.pos <- res$Pos[!is.na(res$Pos)]
+          found.label <- 1:length(found.chr)  ## used for annotation in plot
+      }
+
+
+     # place on -lgo10 scale if manhattan selected
+     if(input$plotchoice=="manhattan"){
+       yvals[is.nan(yvals)] <- 0
+       yvals[yvals < 0] <- 0  ## rounding error - very close to 0 when negative
+       ts <- sqrt(yvals)
+       pval <- 1 - pnorm(ts)
+       logp <- -1*log10(pval)
+       yvals <- logp
+     }
+
+
+     # create data frame for plotting 
+     df <- data.frame(x=xvals, y=yvals, chrm=chrm, pos=pos, foundchr=FALSE, foundpos=FALSE, foundlabel=0 )
+
+     # check for SNP findings from AM
+     if (length(res$Chr)>1){
+          for(ii in 1:length(found.chr)){
+             indx <- which(df$chrm == found.chr[ii])
+             if(!is.null(indx))
+                   df$foundchr[indx] <- TRUE
+             indx <- which(df$pos == found.pos[ii])
+             if(!is.null(indx))
+                   df$foundpos[indx] <- TRUE
+              indx <- which(df$foundchr & df$foundpos & df$foundlabel==0)
+              if(!is.null(indx))
+                   df$foundlabel[indx] <- ii
+       }  ## end for ii
+     }  ## end if length()       
+     geomX <- with(df, x[foundchr&foundpos])
+     geomLabels <- with(df, foundlabel[foundchr&foundpos])
+
+     
+     if(is.null(bigger)){
+       p  <- ggplot(data=df, aes(x=x, y=y )) + geom_point()
+
+     } else {
+       df$Increase <- bigger ## used for color coding points that have increased/decreased from previous iteration 
+       df$Percentagechange <- percentagechange
+
+       p  <- ggplot(data=df, aes(x=x, y=y , color=Increase, size=Percentagechange) )  + geom_point() +  scale_color_manual(values=c("#3b5998","#cae1ff" ))
+    }
+
+  p <- p + theme_hc()
+            p <- p + ylab(ylabel) + xlab(xlabel)
+            p <- p +  theme(legend.title=element_blank())  ## no legend title
+            p <- p + theme(legend.position="right")
+
+            if(!is.null(geomX)){
+              for(ii in geomX){
+               yadj <- sample(seq(0.5,0.9,0.1), 1)
+               p <- p + geom_vline(xintercept = ii, linetype="solid", color="#FFE4B5", size=1.5)
+               p <- p + annotate("text", size=8, label=geomLabels[which(geomX==ii)] , 
+                       x=(ii  - ( diff(range(df$x))*0.02) )   , 
+                        y = max(df$y)*yadj )
+              }  ## end for ii
+              p <- p + scale_size(guide='none')
+            } ## if !is.null
+           p <- p + theme( axis.text.x = element_text(size=16), axis.text.y = element_text(size=16), 
+                           axis.title.x=element_text(size=16), axis.title.y=element_text(size=16), 
+                           legend.text=element_text(size=14) )
+           p <- p  + guides(colour = guide_legend(override.aes = list(size=8)))  ## changing point size in legend
+          
+           p <- p + theme(legend.position = 'bottom', legend.spacing.x = unit(0.5, 'cm')) 
+           output$plot <- renderPlot(p)
+
+           if(input$chosenchrm=="All"){
+              # entire genome
+               txt2 <- "across all chromosomes"
+               if(input$plotchoice=="manhattan"){
+                  txt1 <- " -log p value of the score statistic"
+                  txt3 <- "-log p value"
+               } else {
+                 txt1 <- "score statistic"
+                  txt3 <- txt1
+               } ## inner else
+            } else{
+               # chrm selected
+               txt2 <- paste("on chromosome", input$chosenchrm)
+               if(input$plotchoice=="manhattan"){
+                  txt1 <- " -log p value of the score statistic"
+                  txt3 <- "-log p value"
+               } else {
+                  txt1 <- "score statistic"
+                  txt3 <- txt1
+
+               } ## inner else
+            }  ## end outer else
+         
+           if (input$chosenits==1){
+           txt <- paste("Figure: ", 
+                        "A plot of the", txt1, 
+                        "verse map position", txt2 , 
+                        "at iteration", input$chosenits, 
+                        "of the model building process. The horizontal lines denote the position of SNP found by Eagle to be in association with the trait, ", input$nmst,
+                        ". The numbers are the order in which the SNP-trait associations were found. ")
+
+          } else { 
+           txt <- paste("Figure: ", "A plot of the", txt1, "verse map position", txt2 , "at iteration", input$chosenits, "of the model building process.. The horizontal lines denote the position of SNP found by Eagle to be in association with the trait, ", input$nmst, ". The numbers are the order in which the SNP-trait associations were found.  Dark blue (light blue) points denote a", txt3, "that has decreased (increased) in size from the previous iteration. This is useful for inspecting how different parts of the chromosome gain or lose importance as SNP-trait associations are found. The size of the point is proportional to the size of the increase/decrease.")
+
+          } 
+           output$caption <- renderText(txt)
+
+  })  ## end observeEvent
+
+
+ #--------------------------------------------------
 
  ##--------------------------
  ## Print findings .... 
@@ -1754,7 +2172,7 @@ addPopover(session, "dummy5", "Details", content = HTML(paste("
 By default, the 'best' set of snp in strongest association with the trait are reported. 
 These results are given in table form. 
 <br><br>
-By clicking the 'Additional Summary' button on the left, two additional tables of results are shown; a table on the size and significance of the snp 
+By clicking the 'Additional Summary' button on the left, two additional tables of results are shown; a table on the significance of the snp 
 in the model and a table for the amount of phenotypic variance explained as they are added one at a time to the model.
 <br><br>
 There is additional computation needed to produce these extra tables. It may take a few minutes before these tables appear. 
@@ -1765,6 +2183,14 @@ There is additional computation needed to produce these extra tables. It may tak
 
 
 
+addPopover(session, "plot_overview", "Details", content = HTML(paste("
+Eagle finds SNP-trait associations by building a model iteratively. At each iteration of the model building process, the next 'best' SNP is found. This is done by identifying the SNP with the largest score statistic. A new score statitic is calculated at each iteration of the model building process.<br><br>
+Here, the score statistics or their -log p-values can be plotted. A user can see how these score statistics change as the model is built. Red (blue) points mean the score statistic has increased (decreased) from the previous iteration.   
+<br><br>
+The vertical dotted lines mark the location of the SNP-trait findings. The number is the order in which the SNP-trait associations were found by Eagle. 
+     ", sep="") ), trigger = "hover")
+
+
 
 
  
